==> seedsui-react-5.5.92.tgz: package/lib/Jcrop/原代码/stage/dom.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _get() { if (typeof Reflect !== "undefined" && Reflect.get) { _get = Reflect.get.bind(); } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(arguments.length < 3 ? target : receiver); } return desc.value; }; } return _get.apply(this, arguments); }

function _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import extend from "../util/extend";
import Widget from "../widget";
import Shade from "../shade";
import Dragger from "../dragger";
import ConfObj from "../confobj";
import Sticker from "../sticker";

var Stage = /*#__PURE__*/function (_ConfObj) {
  _inherits(Stage, _ConfObj);

  var _super = _createSuper(Stage);

  function Stage(el, options) {
    var _this;

    _classCallCheck(this, Stage);

    _this = _super.call(this, el, options);
    _this.crops = new Set();
    _this.active = null;
    _this.enabled = true;

    _this.init();

    return _this;
  }

  _createClass(Stage, [{
    key: "init",
    value: function init() {
      this.initStageDrag();
      Shade.Manager.attach(this);
    }
  }, {
    key: "initOptions",
    value: function initOptions() {
      var _this2 = this;

      this._optconf['multi'] = function (v) {
        if (!v) _this2.limitWidgets();
      };
    }
  }, {
    key: "setEnabled",
    value: function setEnabled() {
      var v = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
      var clname = this.options.disabledClass || 'jcrop-disable';
      this[v ? 'removeClass' : 'addClass'](clname);
      this.enabled = !!v;
      return this;
    }
  }, {
    key: "focus",
    value: function focus() {
      if (!this.enabled) return false;
      if (this.active) this.active.el.focus();else this.el.focus();
      return this;
    }
  }, {
    key: "limitWidgets",
    value: function limitWidgets() {
      var n = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 1;
      if (!this.crops || n < 1) return false;
      var crops = Array.from(this.crops);

      while (crops.length > n) {
        this.removeWidget(crops.shift());
      }

      return this;
    }
  }, {
    key: "canCreate",
    value: function canCreate() {
      var n = this.crops.size;
      var o = this.options;
      if (!this.enabled) return false;
      if (o.multiMax !== null && n >= o.multiMax) return false;
      if (!o.multi && n >= o.multiMin) return false;
      return true;
    }
  }, {
    key: "canRemove",
    value: function canRemove() {
      var n = this.crops.size;
      var o = this.options;
      if (!this.enabled) return false;
      if (this.active && !this.active.options.canRemove) return false;
      if (!o.canRemove || n <= o.multiMin) return false;
      return true;
    }
  }, {
    key: "initStageDrag",
    value: function initStageDrag() {
      var _this3 = this;

      var crop, pos, w, h, stick;
      Dragger(this.el, function (x, y, e) {
        if (!_this3.canCreate()) return false;
        crop = (_this3.options.widgetConstructor || Widget).create(_this3.options);
        pos = crop.pos;
        pos.x = e.pageX - _this3.el.offsetParent.offsetLeft - _this3.el.offsetLeft;
        pos.y = e.pageY - _this3.el.offsetParent.offsetTop - _this3.el.offsetTop;
        w = _this3.el.offsetWidth;
        h = _this3.el.offsetHeight;

        _this3.addWidget(crop);

        stick = Sticker.create(pos, w, h, 'se');
        if (_this3.options.aspectRatio) stick.aspect = _this3.options.aspectRatio;
        crop.render(pos);

        _this3.focus();

        return true;
      }, function (x, y) {
        crop.render(stick.move(x, y));
      }, function () {
        crop.emit('crop.change');
      });
    }
  }, {
    key: "reorderWidgets",
    value: function reorderWidgets() {
      var _this4 = this;

      var z = 10;
      this.crops.forEach(function (crop) {
        crop.el.style.zIndex = z++;
        if (_this4.active === crop) crop.addClass('active');else crop.removeClass('active');
      });
      this.refresh();
    }
  }, {
    key: "activate",
    value: function activate(widget) {
      if (!this.enabled) return this;
      widget = widget || Array.from(this.crops).pop();

      if (widget) {
        if (this.active === widget) return;
        this.active = widget;
        this.crops.delete(widget);
        this.crops.add(widget);
        this.reorderWidgets();
        this.active.el.focus();
        this.options.shade && this.shades.enable();
        widget.emit('crop.activate');
      } else {
        this.shades.disable();
      }

      return this;
    }
  }, {
    key: "addWidget",
    value: function addWidget(widget) {
      widget.attachToStage(this);
      widget.appendTo(this.el);
      this.activate(widget);
      return this;
    }
  }, {
    key: "newWidget",
    value: function newWidget(rect) {
      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      options = extend({}, this.options, options);
      var crop = (this.options.widgetConstructor || Widget).create(options);
      crop.render(rect);
      this.addWidget(crop);
      crop.el.focus();
      return crop;
    }
  }, {
    key: "removeWidget",
    value: function removeWidget(widget) {
      if (!this.canRemove()) return false;
      widget.emit('crop.remove');
      widget.el.remove();
      this.crops.delete(widget);
      this.activate();
    }
  }, {
    key: "refresh",
    value: function refresh() {
      this.options.shade && this.active && this.shades.adjust(this.active.pos);
    }
  }, {
    key: "updateShades",
    value: function updateShades() {
      if (!this.shades) return;
      if (this.options.shade) this.shades.enable();else this.shades.disable();
      this.options.shade && this.active && this.shades.adjust(this.active.pos);
      return this;
    }
  }, {
    key: "setOptions",
    value: function setOptions() {
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      _get(_getPrototypeOf(Stage.prototype), "setOptions", this).call(this, options);

      if (this.crops) Array.from(this.crops).forEach(function (i) {
        return i.setOptions(options);
      });
    }
  }, {
    key: "destroy",
    value: function destroy() {}
  }]);

  return Stage;
}(ConfObj);

export default Stage;

==> seedsui-react-5.6.70.tgz: package/lib/Jcrop/原代码/stage/dom.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _get() { if (typeof Reflect !== "undefined" && Reflect.get) { _get = Reflect.get.bind(); } else { _get = function _get(target, property, receiver) { var base = _superPropBase(target, property); if (!base) return; var desc = Object.getOwnPropertyDescriptor(base, property); if (desc.get) { return desc.get.call(arguments.length < 3 ? target : receiver); } return desc.value; }; } return _get.apply(this, arguments); }
function _superPropBase(object, property) { while (!Object.prototype.hasOwnProperty.call(object, property)) { object = _getPrototypeOf(object); if (object === null) break; } return object; }
function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }
function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }
function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }
function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
import extend from "../util/extend";
import Widget from "../widget";
import Shade from "../shade";
import Dragger from "../dragger";
import ConfObj from "../confobj";
import Sticker from "../sticker";
var Stage = /*#__PURE__*/function (_ConfObj) {
  _inherits(Stage, _ConfObj);
  var _super = _createSuper(Stage);
  function Stage(el, options) {
    var _this;
    _classCallCheck(this, Stage);
    _this = _super.call(this, el, options);
    _this.crops = new Set();
    _this.active = null;
    _this.enabled = true;
    _this.init();
    return _this;
  }
  _createClass(Stage, [{
    key: "init",
    value: function init() {
      this.initStageDrag();
      Shade.Manager.attach(this);
    }
  }, {
    key: "initOptions",
    value: function initOptions() {
      var _this2 = this;
      this._optconf['multi'] = function (v) {
        if (!v) _this2.limitWidgets();
      };
    }
  }, {
    key: "setEnabled",
    value: function setEnabled() {
      var v = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
      var clname = this.options.disabledClass || 'jcrop-disable';
      this[v ? 'removeClass' : 'addClass'](clname);
      this.enabled = !!v;
      return this;
    }
  }, {
    key: "focus",
    value: function focus() {
      if (!this.enabled) return false;
      if (this.active) this.active.el.focus();else this.el.focus();
      return this;
    }
  }, {
    key: "limitWidgets",
    value: function limitWidgets() {
      var n = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 1;
      if (!this.crops || n < 1) return false;
      var crops = Array.from(this.crops);
      while (crops.length > n) this.removeWidget(crops.shift());
      return this;
    }
  }, {
    key: "canCreate",
    value: function canCreate() {
      var n = this.crops.size;
      var o = this.options;
      if (!this.enabled) return false;
      if (o.multiMax !== null && n >= o.multiMax) return false;
      if (!o.multi && n >= o.multiMin) return false;
      return true;
    }
  }, {
    key: "canRemove",
    value: function canRemove() {
      var n = this.crops.size;
      var o = this.options;
      if (!this.enabled) return false;
      if (this.active && !this.active.options.canRemove) return false;
      if (!o.canRemove || n <= o.multiMin) return false;
      return true;
    }
  }, {
    key: "initStageDrag",
    value: function initStageDrag() {
      var _this3 = this;
      var crop, pos, w, h, stick;
      Dragger(this.el, function (x, y, e) {
        if (!_this3.canCreate()) return false;
        crop = (_this3.options.widgetConstructor || Widget).create(_this3.options);
        pos = crop.pos;
        pos.x = e.pageX - _this3.el.offsetParent.offsetLeft - _this3.el.offsetLeft;
        pos.y = e.pageY - _this3.el.offsetParent.offsetTop - _this3.el.offsetTop;
        w = _this3.el.offsetWidth;
        h = _this3.el.offsetHeight;
        _this3.addWidget(crop);
        stick = Sticker.create(pos, w, h, 'se');
        if (_this3.options.aspectRatio) stick.aspect = _this3.options.aspectRatio;
        crop.render(pos);
        _this3.focus();
        return true;
      }, function (x, y) {
        crop.render(stick.move(x, y));
      }, function () {
        crop.emit('crop.change');
      });
    }
  }, {
    key: "reorderWidgets",
    value: function reorderWidgets() {
      var _this4 = this;
      var z = 10;
      this.crops.forEach(function (crop) {
        crop.el.style.zIndex = z++;
        if (_this4.active === crop) crop.addClass('active');else crop.removeClass('active');
      });
      this.refresh();
    }
  }, {
    key: "activate",
    value: function activate(widget) {
      if (!this.enabled) return this;
      widget = widget || Array.from(this.crops).pop();
      if (widget) {
        if (this.active === widget) return;
        this.active = widget;
        this.crops.delete(widget);
        this.crops.add(widget);
        this.reorderWidgets();
        this.active.el.focus();
        this.options.shade && this.shades.enable();
        widget.emit('crop.activate');
      } else {
        this.shades.disable();
      }
      return this;
    }
  }, {
    key: "addWidget",
    value: function addWidget(widget) {
      widget.attachToStage(this);
      widget.appendTo(this.el);
      this.activate(widget);
      return this;
    }
  }, {
    key: "newWidget",
    value: function newWidget(rect) {
      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      options = extend({}, this.options, options);
      var crop = (this.options.widgetConstructor || Widget).create(options);
      crop.render(rect);
      this.addWidget(crop);
      crop.el.focus();
      return crop;
    }
  }, {
    key: "removeWidget",
    value: function removeWidget(widget) {
      if (!this.canRemove()) return false;
      widget.emit('crop.remove');
      widget.el.remove();
      this.crops.delete(widget);
      this.activate();
    }
  }, {
    key: "refresh",
    value: function refresh() {
      this.options.shade && this.active && this.shades.adjust(this.active.pos);
    }
  }, {
    key: "updateShades",
    value: function updateShades() {
      if (!this.shades) return;
      if (this.options.shade) this.shades.enable();else this.shades.disable();
      this.options.shade && this.active && this.shades.adjust(this.active.pos);
      return this;
    }
  }, {
    key: "setOptions",
    value: function setOptions() {
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      _get(_getPrototypeOf(Stage.prototype), "setOptions", this).call(this, options);
      if (this.crops) Array.from(this.crops).forEach(function (i) {
        return i.setOptions(options);
      });
    }
  }, {
    key: "destroy",
    value: function destroy() {}
  }]);
  return Stage;
}(ConfObj);
export default Stage;
